@@ -22,17 +22,11 @@ def catRef(humRef, virRef, outputDir):
 #virRef: virus genome
 #newRef: customize genome
 #outputDir: output directory
-def indexRef(bash_file,humRef,virRef,newRef,outputDir):
+def indexRef(bash_file,ref):
     with open(bash_file,'w') as output:
-        output.write(f'''#bwa index {humRef}
-#bwa index {virRef}
-bwa index {newRef}
-#samtools faidx {humRef}
-#samtools faidx {virRef}
-samtools faidx {newRef}
-picard CreateSequenceDictionary R={humRef} O={humRef.replace('.fa','.dict')}
-picard CreateSequenceDictionary R={virRef} O={virRef.replace('.fa','.dict')}
-picard CreateSequenceDictionary R={newRef} O={newRef.replace('.fa','.dict')}
+        output.write(f'''bwa index {ref}
+samtools faidx {ref}
+picard CreateSequenceDictionary R={ref} O={ref.replace('.fa','.dict')}
 ''')
     return None
 
@@ -114,7 +108,7 @@ echo \'indel alignment done\'''')
 
 
 def generate_mkdup_bash(bash_File,out_dir):
-    with open(bash_File,'a') as output:
+    with open(bash_File,'w') as output:
         output.write(f'''
 samtools sort -n {out_dir}/alignment.RG.indelre.bam {out_dir}/alignment.RG.indelre.sortbyQ 
 picard MarkDuplicates \
